<?php
/**
 * @file
 * API Functions for comment_fields
 *
 * @ingroup comment_fields
 * @{
 */

/**
 * Implements hook_comment_fields_info_alter().
 *
 * Alter the value of $info.
 *
 * @param array &$info
 *   The keys of info should be the node type or you can use 'all' for all node
     types. For example if you have $info['page'], then the values of
     $info['page'] will only apply to the node type 'page', but if you wish to
     apply it to all node types then you would need to set it as $info['all'].
 *
 * @return NULL
 *
 * @see comment_fields_info()
 */
function hook_comment_fields_info_alter(&$info) {

  // Feeling and gender are only going to apply to the page node type
  $info['page'] = array(
    'feeling' => array(
      '#title' => t('How did reading this make you feel?'),
      '#type' => 'radios',
      '#default_value' => 'neutral',
      '#options' => array(
        'bad' => t('Bad'),
        'neutral' => t('Indifferent'),
        'good' => t('Good'),
      ),
    ),
    'gender' => array(
      '#title' => t('What is your gender?'),
      '#type' => 'select',
      '#default_value' => 'neutral',
      '#required' => TRUE,
      '#options' => array(
        NULL => t('-Please choose-'),
        'm' => t('Male'),
        'f' => t('Female'),
      ),
    ),
  );

  // The field interest will be added to ALL node types
  $info['all'] = array(
    'interest' => array(
      '#title' => t('Did you find this interesting?'),
      '#type' => 'radios',
      '#default_value' => 'neutral',
      '#options' => array(
        1 => t('Yes'),
        0 => t('No'),
      ),
    ),
  );
}
